summaryrefslogtreecommitdiffstats
path: root/src/mame/drivers/xorworld.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/drivers/xorworld.cpp')
-rw-r--r--src/mame/drivers/xorworld.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/src/mame/drivers/xorworld.cpp b/src/mame/drivers/xorworld.cpp
index e9e8b4caca9..b904f4e300f 100644
--- a/src/mame/drivers/xorworld.cpp
+++ b/src/mame/drivers/xorworld.cpp
@@ -154,22 +154,22 @@ GFXDECODE_END
MACHINE_CONFIG_START(xorworld_state::xorworld)
// basic machine hardware
- MCFG_CPU_ADD("maincpu", M68000, 10000000) // 10 MHz
- MCFG_CPU_PROGRAM_MAP(xorworld_map)
- //MCFG_CPU_VBLANK_INT_DRIVER("screen", xorworld_state, irq6_line_assert) // irq 4 or 6
- //MCFG_CPU_PERIODIC_INT_DRIVER(xorworld_state, irq2_line_assert, 3*60) //timed irq, unknown timing
+ MCFG_DEVICE_ADD("maincpu", M68000, 10000000) // 10 MHz
+ MCFG_DEVICE_PROGRAM_MAP(xorworld_map)
+ //MCFG_DEVICE_VBLANK_INT_DRIVER("screen", xorworld_state, irq6_line_assert) // irq 4 or 6
+ //MCFG_DEVICE_PERIODIC_INT_DRIVER(xorworld_state, irq2_line_assert, 3*60) //timed irq, unknown timing
// Simple fix - but this sounds good!! -Valley Bell
- MCFG_CPU_VBLANK_INT_DRIVER("screen", xorworld_state, irq2_line_assert) // irq 4 or 6
- MCFG_CPU_PERIODIC_INT_DRIVER(xorworld_state, irq6_line_assert, 3*60) //timed irq, unknown timing
+ MCFG_DEVICE_VBLANK_INT_DRIVER("screen", xorworld_state, irq2_line_assert) // irq 4 or 6
+ MCFG_DEVICE_PERIODIC_INT_DRIVER(xorworld_state, irq6_line_assert, 3*60) //timed irq, unknown timing
MCFG_QUANTUM_TIME(attotime::from_hz(60))
MCFG_EEPROM_SERIAL_93C46_ADD("eeprom")
MCFG_DEVICE_ADD("mainlatch", LS259, 0)
- MCFG_ADDRESSABLE_LATCH_Q4_OUT_CB(DEVWRITELINE("eeprom", eeprom_serial_93cxx_device, cs_write)) // CS (active low)
- MCFG_ADDRESSABLE_LATCH_Q5_OUT_CB(DEVWRITELINE("eeprom", eeprom_serial_93cxx_device, clk_write)) // SK (active high)
- MCFG_ADDRESSABLE_LATCH_Q6_OUT_CB(DEVWRITELINE("eeprom", eeprom_serial_93cxx_device, di_write)) // EEPROM data (DIN)
+ MCFG_ADDRESSABLE_LATCH_Q4_OUT_CB(WRITELINE("eeprom", eeprom_serial_93cxx_device, cs_write)) // CS (active low)
+ MCFG_ADDRESSABLE_LATCH_Q5_OUT_CB(WRITELINE("eeprom", eeprom_serial_93cxx_device, clk_write)) // SK (active high)
+ MCFG_ADDRESSABLE_LATCH_Q6_OUT_CB(WRITELINE("eeprom", eeprom_serial_93cxx_device, di_write)) // EEPROM data (DIN)
// video hardware
MCFG_SCREEN_ADD("screen", RASTER)